using System;
using System.Collections;

namespace MapData
{
	/// <summary>
	/// The purpose of this class is to provide a wrapper for the DictionaryBase class.
	/// </summary>
	/// <remarks>
	/// Class:				Dictionary
	/// Programmer:			Edmond Woychowsky
	/// Creation Date:		September 20, 2004
	/// Last Modification:	
	/// </remarks>
	public class Dictionary : DictionaryBase 
	{
		#region publicMethods
		/// <summary>
		/// The purpose of this method is to add or replace key-value pairs in the 
		/// dictionary collection.
		/// </summary>
		/// <param name="key">Item key</param>
		/// <param name="data">Item</param>
		public void Add(object key,object data) 
		{
			if(Contains(key))
				Remove(key);

			this.Dictionary.Add(key, data);
		}

		/// <summary>
		/// The purpose of this method is to remove all key-value pairs from the 
		/// dictionary collection.
		/// </summary>
		public new void Clear() 
		{
			base.Clear();
		}

		/// <summary>
		/// The purpose of this method is to indicate whether a key is already in the 
		/// dictionary collection.
		/// </summary>
		/// <param name="key">Item key</param>
		/// <returns>Dictionary item</returns>
		public bool Contains(object key) 
		{
			return(this.Dictionary.Contains(key));
		}

		/// <summary>
		/// The purpose of this method is to return the number of key-data pairs in the 
		/// dictionary collection.
		/// </summary>
		/// <returns>Number of items in the collection</returns>
		public new int Count() 
		{
			return(this.Dictionary.Count);
		}

		/// <summary>
		/// The purpose of this method is to return the value associated with the 
		/// provided key.
		/// </summary>
		/// <param name="key">Item key</param>
		/// <returns>Dictionary item</returns>
		public object Item(object key) 
		{
			object item = null;

			try 
			{
				item = this.Dictionary[key];
			}
			catch(Exception) { }
			return(item);
		}

		/// <summary>
		/// The purpose of this method is to return all of the keys in the dictionary 
		/// collection.
		/// </summary>
		/// <returns>An array consisting of all of the dictionary keys</returns>
		public object[] Keys() 
		{
			return(new ArrayList(this.Dictionary.Keys).ToArray());
		}

		/// <summary>
		/// The purpose of this method is to remove a key-value pair based upon the 
		/// argument provided.
		/// </summary>
		/// <param name="key">Item key</param>
		public void Remove(object key) 
		{
			this.Dictionary.Remove(key);
		}

		/// <summary>
		/// The purpose of this method is to return all of the values in the dictionary 
		/// collection.
		/// </summary>
		/// <returns>An array consisting of all of the dictionary values</returns>
		public object[] Values() 
		{
			return(new ArrayList(this.Dictionary.Values).ToArray());
		}
		#endregion
	}
}
